from typing import Any, List, Optional, Union

from dev.coatl.helper.types import AnyStr as AnyStr
from java.lang import Comparable, Enum, Object
from org.apache.poi.ss import SpreadsheetVersion
from org.apache.poi.ss.formula.eval import ValueEval
from org.apache.poi.ss.formula.functions import FreeRefFunction, Function
from org.apache.poi.ss.formula.ptg import (
    Area3DPtg,
    Area3DPxg,
    NamePtg,
    NameXPtg,
    NameXPxg,
    Ptg,
    Ref3DPtg,
    Ref3DPxg,
)
from org.apache.poi.ss.formula.udf import UDFFinder
from org.apache.poi.ss.usermodel import (
    Cell,
    CellType,
    ConditionalFormatting,
    ConditionalFormattingRule,
    ConditionType,
    ExcelNumberFormat,
    Sheet,
    Workbook,
)
from org.apache.poi.ss.util import CellRangeAddress, CellRangeAddressBase, CellReference

class EvaluationCell:
    def getArrayFormulaRange(self) -> CellRangeAddress: ...
    def getBooleanCellValue(self) -> bool: ...
    def getCacheFormulaResultType(self) -> CellType: ...
    def getCellType(self) -> CellType: ...
    def getColumnIndex(self) -> int: ...
    def getErrorCellValue(self) -> int: ...
    def getIdentityKey(self) -> Object: ...
    def getNumericCellValue(self) -> float: ...
    def getRowIndex(self) -> int: ...
    def getSheet(self) -> EvaluationSheet: ...
    def getStringCellValue(self) -> AnyStr: ...
    def isPartOfArrayFormulaGroup(self) -> bool: ...

class EvaluationSheet:
    def clearAllCachedResultValues(self) -> None: ...
    def getCell(self, rowIndex: int, columnIndex: int) -> EvaluationCell: ...
    def getLastRowNum(self) -> int: ...
    def isRowHidden(self, rowIndex: int) -> bool: ...

class EvaluationWorkbook:
    class ExternalName(Object):
        def __init__(self, nameName: AnyStr, nameNumber: int, ix: int) -> None: ...
        def getIx(self) -> int: ...
        def getNameName(self) -> AnyStr: ...
        def getNameNumber(self) -> int: ...

    class ExternalSheet(Object):
        def __init__(self, workbookName: AnyStr, sheetName: AnyStr) -> None: ...
        def getSheetName(self) -> AnyStr: ...
        def getWorkbookName(self) -> AnyStr: ...

    class ExternalSheetRange(Object):
        def __init__(
            self, workbookName: AnyStr, firstSheetName: AnyStr, lastSheetName: AnyStr
        ) -> None: ...
        def getFirstSheetName(self) -> AnyStr: ...
        def getLastSheetName(self) -> AnyStr: ...

    def clearAllCachedResultValues(self) -> None: ...
    def convertFromExternSheetIndex(self, externSheetIndex: int) -> int: ...
    def getExternalName(
        self,
        externSheetIndex: int,
        sheetName: int,
        externalWorkbookNumber: Optional[int] = ...,
    ) -> ExternalName: ...
    def getExternalSheet(self, *args: Any) -> ExternalSheet: ...
    def getFormulaTokens(self, cell: EvaluationCell) -> List[Ptg]: ...
    def getName(
        self, name: Union[AnyStr, NamePtg], sheetIndex: Optional[int] = ...
    ) -> ExternalName: ...
    def getSheet(self, sheetIndex: int) -> EvaluationSheet: ...
    def getSheetIndex(self, arg: Union[AnyStr, EvaluationSheet]) -> int: ...
    def getSheetName(self, sheetIndex: int) -> AnyStr: ...
    def getSpreadsheetVersion(self) -> SpreadsheetVersion: ...
    def getUDFFinder(self) -> UDFFinder: ...
    def resolveNameXText(self, ptg: NameXPtg) -> AnyStr: ...

class EvaluationCache(Object):
    def clear(self) -> None: ...
    def getOrCreateFormulaCellEntry(
        self, cell: EvaluationCell
    ) -> FormulaCellCacheEntry: ...
    def getPlainValueEntry(
        self,
        bookIndex: int,
        sheetIndex: int,
        rowIndex: int,
        columnIndex: int,
        value: ValueEval,
    ) -> PlainValueCellCacheEntry: ...
    def notifyDeleteCell(
        self, bookIndex: int, sheetIndex: int, cell: EvaluationCell
    ) -> None: ...
    def notifyUpdateCell(
        self, bookIndex: int, sheetIndex: int, cell: EvaluationCell
    ) -> None: ...

class EvaluationTracker(Object):
    def __init__(self, cache: EvaluationCache) -> None: ...
    def acceptFormulaDependency(self, cce: CellCacheEntry) -> None: ...
    def acceptPlainValueDependency(
        self,
        bookIndex: int,
        sheetIndex: int,
        rowIndex: int,
        columnIndex: int,
        value: ValueEval,
    ) -> None: ...
    def endEvaluate(self, cce: CellCacheEntry) -> None: ...
    def startEvaluate(self, cce: FormulaCellCacheEntry) -> bool: ...
    def updateCacheResult(self, result: ValueEval) -> int: ...

class IEvaluationListener:
    class ICacheEntry:
        def getValue(self) -> ValueEval: ...

    def onCacheHit(self, var1: int, var2: int, var3: int, var4: ValueEval) -> None: ...
    def onReadPlainValue(
        self, var1: int, var2: int, var3: int, var4: ICacheEntry
    ) -> None: ...
    def onStartEvaluate(self, var1: EvaluationCell, var2: ICacheEntry) -> None: ...
    def onClearWholeCache(self) -> None: ...
    def onClearCachedValue(self, var1: ICacheEntry) -> None: ...
    def sortDependentCachedValues(self, var1: List[ICacheEntry]) -> None: ...
    def onClearDependentCachedValues(self, var1: ICacheEntry, var2: int) -> None: ...
    def onChangeFromBlankValue(
        self, var1: int, var2: int, var3: int, var4: ValueEval, var5: ICacheEntry
    ) -> None: ...

class CellCacheEntry(Object, IEvaluationListener.ICacheEntry):
    def addConsumingCell(self, cellLoc: FormulaCellCacheEntry) -> None: ...
    def clearConsumingCell(self, cce: FormulaCellCacheEntry) -> None: ...
    def getConsumingCells(self) -> List[FormulaCellCacheEntry]: ...
    def getValue(self) -> ValueEval: ...
    def recurseClearCachedFormulaResults(
        self, listener: IEvaluationListener
    ) -> None: ...
    def updateValue(self, value: ValueEval) -> None: ...

class ExternSheetReferenceToken:
    def format2DRefAsString(self) -> AnyStr: ...
    def getExternSheetIndex(self) -> int: ...

class FormulaCellCacheEntry(CellCacheEntry):
    def __init__(self) -> None: ...
    def addConsumingCell(self, cellLoc: FormulaCellCacheEntry) -> None: ...
    def changeConsumingCells(self, usedCells: List[CellCacheEntry]) -> None: ...
    def clearFormulaEntry(self) -> None: ...
    def getConsumingCells(self) -> List[FormulaCellCacheEntry]: ...
    def getValue(self) -> ValueEval: ...
    def isInputSensitive(self) -> bool: ...
    def notifyUpdatedBlankCell(
        self,
        bsj: int,
        rowIndex: int,
        columnIndex: int,
        evaluationListener: IEvaluationListener,
    ) -> None: ...
    def recurseClearCachedFormulaResults(
        self, listener: IEvaluationListener
    ) -> None: ...
    def setSensitiveInputCells(
        self, sensitiveInputCells: List[CellCacheEntry]
    ) -> None: ...
    def updateFormulaResult(
        self,
        result: ValueEval,
        sensitiveInputCells: List[CellCacheEntry],
        usedBlankAreas: FormulaUsedBlankCellSet,
    ) -> None: ...
    def updateValue(self, value: ValueEval) -> None: ...

class FormulaUsedBlankCellSet(Object):
    class BlankCellRectangleGroup(Object):
        def __init__(
            self, firstRowIndex: int, firstColumnIndex: int, lastColumnIndex: int
        ) -> None: ...
        def containsCell(self, rowIndex: int, columnIndex: int) -> bool: ...
        def acceptRow(
            self, rowIndex: int, firstColumnIndex: int, lastColumnIndex: int
        ) -> bool: ...

    class BlankCellSheetGroup(Object):
        def __init__(self, lastDefinedRow: int) -> None: ...
        def addCell(self, rowIndex: int, columnIndex: int) -> None: ...
        def containsCell(self, rowIndex: int, columnIndex: int) -> bool: ...

    class BookSheetKey(Object):
        def __init__(self, bookIndex: int, sheetIndex: int) -> None: ...

    def addCell(
        self,
        evalWorkbook: EvaluationWorkbook,
        bookIndex: int,
        sheetIndex: int,
        rowIndex: int,
        columnIndex: int,
    ) -> None: ...
    def getSheetGroup(
        self, evalWorkbook: EvaluationWorkbook, bookIndex: int, sheetIndex: int
    ) -> BlankCellSheetGroup: ...
    def containsCell(
        self, key: BookSheetKey, rowIndex: int, columnIndex: int
    ) -> bool: ...
    def isEmpty(self) -> bool: ...

class PlainValueCellCacheEntry(CellCacheEntry):
    def __init__(self, value: ValueEval) -> None: ...
    def addConsumingCell(self, cellLoc: FormulaCellCacheEntry) -> None: ...
    def clearConsumingCell(self, cce: FormulaCellCacheEntry) -> None: ...
    def getConsumingCells(self) -> List[FormulaCellCacheEntry]: ...
    def getValue(self) -> ValueEval: ...
    def recurseClearCachedFormulaResults(
        self, listener: IEvaluationListener
    ) -> None: ...
    def updateValue(self, value: ValueEval) -> None: ...

class SheetRange:
    def getFirstSheetIndex(self) -> int: ...
    def getLastSheetIndex(self) -> int: ...

class SheetRefEvaluator(Object):
    def __init__(
        self,
        bookEvaluator: WorkbookEvaluator,
        tracker: EvaluationTracker,
        sheetIndex: int,
    ) -> None: ...
    def getEvalForCell(self, rowIndex: int, columnIndex: int) -> ValueEval: ...
    def getSheet(self) -> EvaluationSheet: ...
    def getSheetName(self) -> AnyStr: ...
    def isSubTotal(self, rowIndex: int, columnIndex: int) -> bool: ...
    def isRowHidden(self, rowIndex: int) -> bool: ...

class SheetRangeEvaluator(Object, SheetRange):
    def __init__(
        self,
        firstSheetIndex: int,
        lastSheetIndex: int,
        sheetEvaluators: List[SheetRefEvaluator],
    ) -> None: ...
    def getEvalForCell(
        self, sheetIndex: int, rowIndex: int, columnIndex: int
    ) -> ValueEval: ...
    def getFirstSheetIndex(self) -> int: ...
    def getLastSheetIndex(self) -> int: ...
    def getSheetEvaluator(self, sheetIndex: int) -> SheetRefEvaluator: ...
    def getSheetName(self, sheetIndex: int) -> AnyStr: ...
    def getSheetNameRange(self) -> AnyStr: ...

class OperationEvaluationContext(Object):
    UDF: FreeRefFunction
    def __init__(
        self,
        bookEvaluator: WorkbookEvaluator,
        workbook: EvaluationWorkbook,
        sheetIndex: int,
        srcRowNum: int,
        srcColNum: int,
        tracker: EvaluationTracker,
        isSingleValue: bool = ...,
    ) -> None: ...
    def findUserDefinedFunction(self, name: AnyStr) -> FreeRefFunction: ...
    def getArea3DEval(self, aptg: Union[Area3DPtg, Area3DPxg]) -> ValueEval: ...
    def getAreaEval(
        self,
        firstRowIndex: int,
        firstColumnIndex: int,
        lastRowIndex: int,
        lastColumnIndex: int,
    ) -> ValueEval: ...
    def getAreaValueEval(
        self,
        firstRowIndex: int,
        firstColumnIndex: int,
        lastRowIndex: int,
        lastColumnIndex: int,
        tokens: List[Object],
    ) -> ValueEval: ...
    def getColumnIndex(self) -> int: ...
    def getDynamicReference(
        self,
        workbookName: AnyStr,
        sheetName: AnyStr,
        refStrPart1: AnyStr,
        refStrPart2: AnyStr,
        isA1Style: bool,
    ) -> ValueEval: ...
    def getNameXEval(self, arg: Union[NameXPtg, NameXPxg]) -> ValueEval: ...
    def getRef3DEval(self, arg: Union[Ref3DPtg, Ref3DPxg]) -> ValueEval: ...
    def getRefEval(self, rowIndex: int, colIndex: int) -> ValueEval: ...
    def getRefEvaluatorForCurrentSheet(self) -> SheetRangeEvaluator: ...
    def getRowIndex(self) -> int: ...
    def getSheetIndex(self) -> int: ...
    def getWorkbook(self) -> EvaluationWorkbook: ...
    def isArrayMode(self) -> bool: ...
    def isSingleValue(self) -> bool: ...
    def setArrayMode(self, value: bool) -> None: ...

class IStabilityClassifier:
    TOTALLY_IMMUTABLE: IStabilityClassifier
    def isCellFinal(self, sheetIndex: int, rowIndex: int, columnIndex: int) -> bool: ...

class WorkbookDependentFormula:
    def toFormulaString(self) -> AnyStr: ...

class WorkbookEvaluator(Object):
    def __init__(
        self,
        workbook: EvaluationWorkbook,
        stabilityClassifier: IStabilityClassifier,
        udfFinder: UDFFinder,
    ) -> None: ...
    def clearAllCachedResultValues(self) -> None: ...
    @staticmethod
    def dereferenceResult(
        evaluationResult: ValueEval, srcRowNum: int, srcColNum: int
    ) -> ValueEval: ...
    def evaluate(self, *args: Any) -> ValueEval: ...
    def evaluateList(
        self, formula: AnyStr, target: CellReference, region: CellRangeAddressBase
    ) -> ValueEval: ...
    def findUserDefinedFunction(self, name: AnyStr) -> FreeRefFunction: ...
    @staticmethod
    def getNotSupportedFunctionNames() -> List[AnyStr]: ...
    @staticmethod
    def getSupportedFunctionNames() -> List[AnyStr]: ...
    def isDebugEvaluationOutpotForNextEval(self) -> bool: ...
    def isIgnoreMissingWorkbooks(self) -> bool: ...
    def notifyDeleteCell(self, cell: EvaluationCell) -> None: ...
    def notifyUpdateCell(self, cell: EvaluationCell) -> None: ...
    @staticmethod
    def registerFunction(
        name: AnyStr, func: Union[FreeRefFunction, Function]
    ) -> None: ...
    def setDebugEvaluationOutputForNextEval(self, value: bool) -> None: ...
    def setIgnoreMissingWorkbooks(self, ignore: bool) -> None: ...

class WorkbookEvaluatorProvider: ...

class EvaluationConditionalFormatRule(Object, Comparable):
    class OperatorEnum(Enum):
        BETWEEN: EvaluationConditionalFormatRule.OperatorEnum
        EQUAL: EvaluationConditionalFormatRule.OperatorEnum
        GREATER_OR_EQUAL: EvaluationConditionalFormatRule.OperatorEnum
        GREATER_THAN: EvaluationConditionalFormatRule.OperatorEnum
        LESS_OR_EQUAL: EvaluationConditionalFormatRule.OperatorEnum
        LESS_THAN: EvaluationConditionalFormatRule.OperatorEnum
        NO_COMPARISON: EvaluationConditionalFormatRule.OperatorEnum
        NOT_BETWEEN: EvaluationConditionalFormatRule.OperatorEnum
        NOT_EQUAL: EvaluationConditionalFormatRule.OperatorEnum
        def isValid(self, *args: Comparable) -> bool: ...
        def isValidForCompatibleTypes(self) -> bool: ...
        @staticmethod
        def values() -> List[EvaluationConditionalFormatRule.OperatorEnum]: ...

    def __init__(
        self,
        workbookEvaluator: WorkbookEvaluator,
        sheet: Sheet,
        formatting: ConditionalFormatting,
        formattingIndex: int,
        rule: ConditionalFormattingRule,
        ruleIndex: int,
        regions: List[CellRangeAddress],
    ) -> None: ...
    def compareTo(self, o: Any) -> int: ...
    def getFormatting(self) -> ConditionalFormatting: ...
    def getFormattingIndex(self) -> int: ...
    def getFormula1(self) -> AnyStr: ...
    def getFormula2(self) -> AnyStr: ...
    def getNumberFormat(self) -> ExcelNumberFormat: ...
    def getOperator(self) -> EvaluationConditionalFormatRule.OperatorEnum: ...
    def getPriority(self) -> int: ...
    def getRegions(self) -> List[CellRangeAddress]: ...
    def getRule(self) -> ConditionalFormattingRule: ...
    def getRuleIndex(self) -> int: ...
    def getSheet(self) -> Sheet: ...
    def getText(self) -> AnyStr: ...
    def getType(self) -> ConditionType: ...

class ConditionalFormattingEvaluator(Object):
    def __init__(self, wb: Workbook, provider: WorkbookEvaluatorProvider) -> None: ...
    def clearAllCachedFormats(self) -> None: ...
    def clearAllCachedValues(self) -> None: ...
    def getConditionalFormattingForCell(
        self, cell: Union[Cell, CellReference]
    ) -> List[EvaluationConditionalFormatRule]: ...
    def getFormatRulesForSheet(
        self, sheet: Union[AnyStr, Sheet]
    ) -> List[EvaluationConditionalFormatRule]: ...
    def getMatchingCells(self, *args: Any) -> List[Cell]: ...
    @staticmethod
    def getRef(cell: Cell) -> CellReference: ...



from typing import Any, List, Optional, Union

from dev.coatl.helper.types import AnyStr as AnyStr
from java.lang import Comparable, Enum, Object
from org.apache.poi.common import Duplicatable
from org.apache.poi.ss import SpreadsheetVersion
from org.apache.poi.util import LittleEndianOutput

class AreaReference(Object):
    def __init__(self, *args: Any) -> None: ...
    def formatAsString(self) -> AnyStr: ...
    @staticmethod
    def generateContiguous(
        version: SpreadsheetVersion, reference: AnyStr
    ) -> List[AreaReference]: ...
    def getAllReferencedCells(self) -> List[CellReference]: ...
    def getFirstCell(self) -> CellReference: ...
    def getLastCell(self) -> CellReference: ...
    @staticmethod
    def getWholeColumn(
        version: SpreadsheetVersion, start: AnyStr, end: AnyStr
    ) -> AreaReference: ...
    @staticmethod
    def getWholeRow(
        version: SpreadsheetVersion, start: AnyStr, end: AnyStr
    ) -> AreaReference: ...
    def isSingleCell(self) -> bool: ...
    @staticmethod
    def isWholeColumnReference(
        version: Optional[SpreadsheetVersion] = ...,
        topLeft: Optional[CellReference] = ...,
        botRight: Optional[CellReference] = ...,
    ) -> bool: ...

class CellAddress(Object, Comparable):
    def __init__(self, *args: Any) -> None: ...
    def compareTo(self, o: Any) -> int: ...
    def formatAsString(self) -> AnyStr: ...
    def getColumn(self) -> int: ...
    def getRow(self) -> int: ...

class CellRangeAddressBase(Object, Duplicatable):
    class CellPosition(Enum):
        BOTTOM: CellRangeAddressBase.CellPosition
        LEFT: CellRangeAddressBase.CellPosition
        RIGHT: CellRangeAddressBase.CellPosition
        TOP: CellRangeAddressBase.CellPosition
        @staticmethod
        def values() -> List[CellRangeAddressBase.CellPosition]: ...

    def containsColumn(self, colInd: int) -> bool: ...
    def containsRow(self, rowInd: int) -> bool: ...
    def copy(self) -> Duplicatable: ...
    def getFirstColumn(self) -> int: ...
    def getFirstRow(self) -> int: ...
    def getLastColumn(self) -> int: ...
    def getLastRow(self) -> int: ...
    def getNumberOfCells(self) -> int: ...
    def getPosition(self, rowInd: int, colInd: int) -> Any: ...
    def intersects(self, other: CellRangeAddressBase) -> bool: ...
    def isFullColumnRange(self) -> bool: ...
    def isFullRowRange(self) -> bool: ...
    def isInRange(self, *args: Any) -> bool: ...
    def iterator(self) -> Any: ...
    def setFirstColumn(self, firstCol: int) -> None: ...
    def setFirstRow(self, firstRow: int) -> None: ...
    def setLastColumn(self, lastCol: int) -> None: ...
    def setLastRow(self, lastRow: int) -> None: ...
    def validate(self, ssVesion: SpreadsheetVersion) -> None: ...

class CellRangeAddress(CellRangeAddressBase):
    ENCODED_SIZE: int
    def __init__(self, *args: Any) -> None: ...
    def formatAsString(
        self, sheetName: Optional[AnyStr] = ..., useAbsoluteAddress: bool = ...
    ) -> AnyStr: ...
    @staticmethod
    def getEncodedSize() -> int: ...
    def serialize(self, out: LittleEndianOutput) -> None: ...
    @staticmethod
    def valueOf(ref: AnyStr) -> CellRangeAddress: ...

class CellRangeAddressList(Object):
    def __init__(self, *args: Any) -> None: ...
    def addCellRangeAddress(self, *args: Any) -> None: ...
    def copy(self) -> CellRangeAddressList: ...
    def countRanges(self) -> int: ...
    def getCellRangeAddress(self, index: int) -> CellRangeAddress: ...
    def getCellRangeAddresses(self) -> List[CellRangeAddress]: ...
    @staticmethod
    def getEncodedSize(numberOfRanges: int) -> int: ...
    def getSize(self) -> int: ...
    def remove(self, rangeIdex: int) -> CellRangeAddress: ...
    def serialize(self, *args: Any) -> None: ...

class CellReference(Object):
    class NameType(Enum):
        BAD_CELL_OR_NAMED_RANGE: CellReference.NameType
        CELL: CellReference.NameType
        COLUMN: CellReference.NameType
        NAMED_RANGE: CellReference.NameType
        ROW: CellReference.NameType
        @staticmethod
        def values() -> List[CellReference.NameType]: ...

    def __init__(self, *args: Any) -> None: ...
    @staticmethod
    def cellReferenceIsWithinRange(
        colStr: AnyStr, rowStr: AnyStr, ssVersion: SpreadsheetVersion
    ) -> bool: ...
    @staticmethod
    def classifyCellReference(
        str_: AnyStr, ssVersion: SpreadsheetVersion
    ) -> CellReference.NameType: ...
    @staticmethod
    def convertColStringToIndex(ref: AnyStr) -> int: ...
    @staticmethod
    def converNumToColString(col: int) -> AnyStr: ...
    def formatAsString(self, includeSheetName: bool = ...) -> AnyStr: ...
    def getCellRefParts(self) -> List[AnyStr]: ...
    def getCol(self) -> int: ...
    def getRow(self) -> int: ...
    def getSheetName(self) -> AnyStr: ...
    def isColAbsolute(self) -> bool: ...
    @staticmethod
    def isColumnWithinRange(colStr: AnyStr, ssVersion: SpreadsheetVersion) -> bool: ...
    @staticmethod
    def isPartAbsolute(part: AnyStr) -> bool: ...
    def isRowAbsolute(self) -> bool: ...
    @staticmethod
    def isRowWithinRange(
        rowNumOrStr: Union[int, AnyStr], ssVersion: SpreadsheetVersion
    ) -> bool: ...

class PaneInformation(Object):
    PANE_LOWER_LEFT: int
    PANE_LOWER_RIGHT: int
    PANE_UPPER_LEFT: int
    PANE_UPPER_RIGHT: int
    def __init__(
        self, x: int, y: int, top: int, left: int, active: int, frozen: bool
    ) -> None: ...
    def getActivePane(self) -> int: ...
    def getHorizontalSplitPosition(self) -> int: ...
    def getHorizontalSplitTopRow(self) -> int: ...
    def getVerticalSplitLeftColumn(self) -> int: ...
    def getVerticalSplitPosition(self) -> int: ...
    def isFreezePane(self) -> bool: ...



from typing import Any, Dict, List

from dev.coatl.helper.types import AnyStr
from java.lang import Comparable, Object
from java.time import Instant, LocalTime, ZoneId, ZoneOffset
from java.time.format import DateTimeFormatter, ResolverStyle, TextStyle
from java.time.temporal import (
    ChronoField,
    Temporal,
    TemporalAccessor,
    TemporalAdjuster,
    TemporalAmount,
    TemporalField,
    TemporalUnit,
    ValueRange,
)
from java.util import Comparator, Locale

class ChronoLocalDate(Temporal, TemporalAdjuster, Comparable):
    def adjustInto(self, temporal: Temporal) -> Temporal: ...
    def atTime(self, localTime: LocalTime) -> ChronoLocalDateTime: ...
    def compareTo(self, o: ChronoLocalDate) -> int: ...
    def equals(self, obj: Any) -> bool: ...
    def format(self, formatter: DateTimeFormatter) -> AnyStr: ...
    def getChronology(self) -> Chronology: ...
    def getEra(self) -> Era: ...
    def hashCode(self) -> int: ...
    def isAfter(self, other: ChronoLocalDate) -> bool: ...
    def isBefore(self, other: ChronoLocalDate) -> bool: ...
    def isEqual(self, other: ChronoLocalDate) -> bool: ...
    def isLeapYear(self) -> bool: ...
    def lengthOfMonth(self) -> int: ...
    def lengthOfYear(self) -> int: ...
    @staticmethod
    def timeLineOrder() -> Comparator: ...
    def toEpochDay(self) -> long: ...
    def toString(self) -> AnyStr: ...
    def until(self, endExclusive: Temporal, unit: TemporalUnit) -> long: ...

class ChronoLocalDateTime(Temporal, TemporalAdjuster, Comparable):
    def atZone(self, zone: ZoneId) -> ChronoZonedDateTime: ...
    def toLocalDate(self) -> Any: ...
    def toLocalTime(self) -> LocalTime: ...
    def toString(self) -> AnyStr: ...

class ChronoPeriod(TemporalAmount):
    @staticmethod
    def between(
        startDateInclusive: ChronoLocalDate, endDateExclusive: ChronoLocalDate
    ) -> ChronoPeriod: ...
    def equals(self, obj: Object) -> bool: ...
    def getChronology(self) -> Chronology: ...
    def hashCode(self) -> int: ...
    def isNegative(self) -> bool: ...
    def isZero(self) -> bool: ...
    def minus(self, amountToSubtract: TemporalAmount) -> ChronoPeriod: ...
    def multipliedBy(self, scalar: int) -> ChronoPeriod: ...
    def negated(self) -> ChronoPeriod: ...
    def normalized(self) -> ChronoPeriod: ...
    def plus(self, amountToAdd: TemporalAmount) -> ChronoPeriod: ...
    def toString(self) -> AnyStr: ...

class ChronoZonedDateTime(Temporal, Comparable):
    def format(self, formatter: DateTimeFormatter) -> AnyStr: ...
    def getChronology(self) -> Chronology: ...
    def getOffset(self) -> ZoneOffset: ...
    def getZone(self) -> ZoneId: ...
    def isAfter(self, other: ChronoZonedDateTime) -> bool: ...
    def isBefore(self, other: ChronoZonedDateTime) -> bool: ...
    def isEqual(self, other: ChronoZonedDateTime) -> bool: ...
    @staticmethod
    def timeLineOrder() -> Comparator: ...
    def toEpochSecond(self) -> long: ...
    def toInstant(self) -> Instant: ...
    def toLocalDate(self) -> Any: ...
    def toLocalDateTime(self) -> ChronoLocalDateTime: ...
    def toLocalTime(self) -> LocalTime: ...
    def withEarlierOffsetAtOverlap(self) -> ChronoZonedDateTime: ...
    def withLaterOffsetAtOverlap(self) -> ChronoZonedDateTime: ...
    def withZoneSameInstant(self, zone: ZoneId) -> ChronoZonedDateTime: ...
    def withZoneSameLocal(self, zone: ZoneId) -> ChronoZonedDateTime: ...

class Chronology(Comparable):
    def date(self, *args: Any) -> ChronoLocalDate: ...
    def dateEpochDay(self, epochDay: long) -> ChronoLocalDate: ...
    def dateYearDay(self, prolepticYear: int, dayOfYear: int) -> ChronoLocalDate: ...
    def equals(self, obj: Object) -> bool: ...
    def eraOf(self, eraValue: int) -> Era: ...
    def eras(self) -> List[Era]: ...
    def getCalendarType(self) -> AnyStr: ...
    def getId(self) -> AnyStr: ...
    def hashCode(self) -> int: ...
    def isLeapYear(self, prolepticYear: long) -> bool: ...
    def prolepticYear(self, era: Era, yearOfEra: int) -> int: ...
    def range(self, field: ChronoField) -> ValueRange: ...
    def resolveDate(
        self, fieldValues: Dict[TemporalField, long], resolverStyle: ResolverStyle
    ) -> ChronoLocalDate: ...
    def toString(self) -> AnyStr: ...

class Era(TemporalAccessor, TemporalAdjuster):
    def adjustInto(self, temporal: Temporal) -> Temporal: ...
    def getDisplayName(self, style: TextStyle, locale: Locale) -> long: ...
    def getValue(self) -> int: ...



from typing import List

from dev.coatl.helper.types import AnyStr as AnyStr
from java.lang import Enum

class SpreadsheetVersion(Enum):
    def getLastColumnIndex(self) -> int: ...
    def getLastColumnName(self) -> AnyStr: ...
    def getLastRowIndex(self) -> int: ...
    def getMaxCellStyles(self) -> int: ...
    def getMaxColumns(self) -> int: ...
    def getMaxConditionalFormats(self) -> int: ...
    def getMaxFunctionArgs(self) -> int: ...
    def getMaxRows(self) -> int: ...
    def getMaxTextLength(self) -> int: ...
    @staticmethod
    def getValueOf(name: AnyStr) -> SpreadsheetVersion: ...
    @staticmethod
    def values() -> List[SpreadsheetVersion]: ...



from typing import Any

from java.lang import Object

class ClassID(Object):
    EQUATION30: ClassID
    EXCEL_V3: ClassID
    EXCEL_V3_CHART: ClassID
    EXCEL_V3_MACRO: ClassID
    EXCEL2003: ClassID
    EXCEL2007: ClassID
    EXCEL2007_MACRO: ClassID
    EXCEL2007_XLSB: ClassID
    EXCEL2010: ClassID
    EXCEL2010_CHART: ClassID
    EXCEL2010_ODS: ClassID
    EXCEL95: ClassID
    EXCEL95_CHART: ClassID
    EXCEL97: ClassID
    EXCEL97_CHART: ClassID
    LENGTH: ClassID
    OLE10_PACKAGE: ClassID
    POWERPOINT2007: ClassID
    POWERPOINT2007_MACRO: ClassID
    POWERPOINT95: ClassID
    POWERPOINT97: ClassID
    PPT_SHOW: ClassID
    TXT_ONLY: ClassID
    WORD2007: ClassID
    WORD2007_MACRO: ClassID
    WORD95: ClassID
    WORD97: ClassID
    XLS_WORKBOOK: ClassID
    def __init__(self, *args: Any) -> None: ...
    def copy(self) -> ClassID: ...
    def equalsInverted(self, o: ClassID) -> bool: ...
    def getBytes(self) -> bytes: ...
    def length(self) -> int: ...
    def read(self, src: bytes, offset: int) -> None: ...
    def setBytes(self, bytes_: bytes) -> None: ...
    def write(self, *args: Any) -> None: ...



from typing import Any, List, Mapping, Optional, Set

from dev.coatl.helper.types import AnyStr
from java.io import Closeable, InputStream, IOException, OutputStream
from java.lang import Class, Enum, Object
from java.nio.channels import SocketChannel

class SocketAddress(Object):
    def __init__(self) -> None: ...

class CookiePolicy:
    def shouldAccept(self, uri: URI, cookie: HttpCookie) -> bool: ...

class CookieStore:
    def add(self, uri: URI, cookie: HttpCookie) -> None: ...
    def get(self, uri: URI) -> List[HttpCookie]: ...
    def getCookies(self) -> List[HttpCookie]: ...
    def getURIs(self) -> List[URI]: ...
    def remove(self, uri: URI, cookie: HttpCookie) -> bool: ...
    def removeAll(self) -> bool: ...

class FileNameMap:
    def getContentTypeFor(self, fileName: AnyStr) -> AnyStr: ...

class SocketImplFactory:
    def createSocketImpl(self) -> SocketImpl: ...

class SocketOption:
    def name(self) -> AnyStr: ...
    def type(self) -> Class: ...

class CookieHandler(Object):
    def __init__(self) -> None: ...
    def get(
        self, uri: URI, requestHeaders: Mapping[AnyStr, List[AnyStr]]
    ) -> Mapping[AnyStr, List[AnyStr]]: ...
    @staticmethod
    def getDefault() -> CookieHandler: ...
    def put(
        self, uri: URI, responseHeaders: Mapping[AnyStr, List[AnyStr]]
    ) -> Mapping[AnyStr, List[AnyStr]]: ...
    @staticmethod
    def setDefault(cHandler: CookieHandler) -> None: ...

class CookieManager(CookieHandler):
    def __init__(self, *args: Any) -> None: ...
    def get(
        self, uri: URI, requestHeaders: Mapping[AnyStr, List[AnyStr]]
    ) -> Mapping[AnyStr, List[AnyStr]]: ...
    def getCookieStore(self) -> CookieStore: ...
    def put(
        self, uri: URI, responseHeaders: Mapping[AnyStr, List[AnyStr]]
    ) -> Mapping[AnyStr, List[AnyStr]]: ...
    def setCookiePolicy(self, cookiePolicy: CookiePolicy) -> None: ...

class HttpCookie(Object):
    def __init__(self, name: AnyStr, value: AnyStr) -> None: ...

class InetAddress(Object):
    def getAddress(self) -> bytearray: ...
    @staticmethod
    def getAllByName(host: AnyStr) -> List[InetAddress]: ...
    @staticmethod
    def getByAddress(*args: Any) -> InetAddress: ...
    @staticmethod
    def getByName(host: AnyStr) -> InetAddress: ...
    def getCanonicalHostName(self) -> AnyStr: ...
    def getHostAddress(self) -> AnyStr: ...
    def getHostName(self) -> AnyStr: ...
    @staticmethod
    def getLocalHost() -> InetAddress: ...
    @staticmethod
    def getLoopbackAddress() -> InetAddress: ...
    def isAnyLocalAddress(self) -> bool: ...
    def isLinkLocalAddress(self) -> bool: ...
    def isLoopbackAddress(self) -> bool: ...
    def isMCGlobal(self) -> bool: ...
    def isMCLinkLocal(self) -> bool: ...
    def isMCNodeLocal(self) -> bool: ...
    def isMCOrgLocal(self) -> bool: ...
    def isMCSiteLocal(self) -> bool: ...
    def isMulticastAddress(self) -> bool: ...
    def isReachable(self, *args: Any) -> bool: ...
    def isSiteLocalAddress(self) -> bool: ...

class InetSocketAddress(SocketAddress):
    def __init__(self, *args: Any) -> None: ...
    @staticmethod
    def createUnresolved(host: AnyStr, port: int) -> InetSocketAddress: ...
    def getAddress(self) -> InetAddress: ...
    def getHostname(self) -> AnyStr: ...
    def getHostString(self) -> AnyStr: ...
    def getPort(self) -> int: ...
    def isUnresolved(self) -> bool: ...

class Proxy(Object):
    class Type(Enum):
        DIRECT: Proxy.Type
        HTTP: Proxy.Type
        SOCKS: Proxy.Type
        @staticmethod
        def values() -> List[Proxy.Type]: ...

    NO_PROXY: Proxy
    def __init__(self, type_: Proxy.Type, sa: SocketAddress) -> None: ...
    def address(self) -> SocketAddress: ...
    def type(self) -> Proxy.Type: ...

class Socket(Object, Closeable):
    def __init__(self, *args: Any) -> None: ...
    def bind(self, bindpoint: SocketAddress) -> None: ...
    def close(self) -> None: ...
    def connect(
        self, endpoint: SocketAddress, timeout: Optional[int] = ...
    ) -> None: ...
    def getChannel(self) -> SocketChannel: ...
    def getInetAddress(self) -> InetAddress: ...
    def getInputStream(self) -> InputStream: ...
    def getKeepAlive(self) -> bool: ...
    def getLocalAddress(self) -> InetAddress: ...
    def getLocalPort(self) -> int: ...
    def getLocalSocketAddress(self) -> SocketAddress: ...
    def getOOBInline(self) -> bool: ...
    def getOption(self, name: SocketOption) -> Any: ...
    def getOutputStream(self) -> OutputStream: ...
    def getPort(self) -> int: ...
    def getReceiveBufferSize(self) -> int: ...
    def getRemoteSocketAddress(self) -> SocketAddress: ...
    def getReuseAddress(self) -> bool: ...
    def getSendBufferSize(self) -> int: ...
    def getSoLinger(self) -> int: ...
    def getSoTimeout(self) -> int: ...
    def getTcpNoDelay(self) -> bool: ...
    def getTrafficClass(self) -> int: ...
    def isBound(self) -> bool: ...
    def isClosed(self) -> bool: ...
    def isConnected(self) -> bool: ...
    def isInputShutdown(self) -> bool: ...
    def isOutputShutdown(self) -> bool: ...
    def sendUrgentData(self, data: int) -> None: ...
    def setKeepAlive(self, on: bool) -> None: ...
    def setOOBInline(self, on: bool) -> None: ...
    def setOption(self, name: SocketOption, value: Any) -> Socket: ...
    def setPerformancePreferences(
        self, connectionTime: int, latency: int, bandwidth: int
    ) -> None: ...
    def setReceiveBufferSize(self, size: int) -> None: ...
    def setReuseAddress(self, on: bool) -> None: ...
    def setSendBufferSize(self, size: int) -> None: ...
    @staticmethod
    def setSocketImplFactory(fac: SocketImplFactory) -> None: ...
    def setSoLinger(self, on: bool, linger: int) -> None: ...
    def setSoTimeout(self, timeout: int) -> None: ...
    def setTcpNoDelay(self, on: bool) -> None: ...
    def setTrafficClass(self, tc: int) -> None: ...
    def shutdownInput(self) -> None: ...
    def shutdownOutput(self) -> None: ...
    def supportedOptions(self) -> Set[SocketOption]: ...

class SocketImpl(Object):
    def __init__(self) -> None: ...

class URI(Object):
    def __init__(self, *args: Any) -> None: ...

class UnknownHostException(IOException):
    def __init__(self, message: Optional[str] = ...) -> None: ...



from typing import Any, Dict, List, Optional, Set, Union

from dev.coatl.helper.types import AnyStr
from java.lang import CharSequence, Comparable, Enum, Object
from java.time.chrono import ChronoLocalDateTime, ChronoZonedDateTime
from java.time.format import DateTimeFormatter, TextStyle
from java.time.temporal import (
    Temporal,
    TemporalAccessor,
    TemporalAdjuster,
    TemporalUnit,
)
from java.util import Locale

class Clock(Object):
    @staticmethod
    def offset(baseClock: Instant, offsetDuration: ZoneId) -> Clock: ...
    @staticmethod
    def systemDefaultZone() -> Clock: ...
    @staticmethod
    def systemUTC() -> Clock: ...
    @staticmethod
    def tick(baseClock: Clock, tickDuration: Duration) -> Clock: ...
    @staticmethod
    def tickMillis(zone: ZoneId) -> Clock: ...
    @staticmethod
    def tickMinutes(zone: ZoneId) -> Clock: ...
    @staticmethod
    def tickSeconds(zone: ZoneId) -> Clock: ...

class DayOfWeek(Enum, TemporalAccessor, TemporalAdjuster):
    FRIDAY: DayOfWeek
    MONDAY: DayOfWeek
    SATURDAY: DayOfWeek
    SUNDAY: DayOfWeek
    THURSDAY: DayOfWeek
    TUESDAY: DayOfWeek
    WEDNESDAY: DayOfWeek
    def getValue(self) -> int: ...
    def minus(self, days: long) -> DayOfWeek: ...
    @staticmethod
    def of(dayOfWeek: int) -> DayOfWeek: ...
    def plus(self, days: long) -> DayOfWeek: ...
    @staticmethod
    def values() -> List[DayOfWeek]: ...

class Duration(Object):
    ZERO: Duration
    def toDays(self) -> long: ...
    def toDaysPart(self) -> long: ...
    def toHours(self) -> long: ...
    def toHoursPart(self) -> int: ...
    def toMillis(self) -> long: ...
    def toMillisPart(self) -> int: ...
    def toMinutes(self) -> long: ...
    def toMinutesPart(self) -> int: ...
    def toNanos(self) -> long: ...
    def toNanosPart(self) -> int: ...
    def toSeconds(self) -> long: ...
    def toSecondsPart(self) -> int: ...

class Instant(Object):
    EPOCH: Instant
    MAX: Instant
    MIN: Instant
    @staticmethod
    def now(clock: Optional[Clock] = ...) -> Instant: ...
    @staticmethod
    def ofEpochMilli(epochMilli: long) -> Instant: ...
    @staticmethod
    def ofEpochSecond(
        epochSecond: long, nanoAdjustment: Optional[long] = ...
    ) -> Instant: ...
    @staticmethod
    def parse(text: CharSequence) -> Instant: ...

class LocalDate(Object, Temporal, TemporalAdjuster, Comparable):
    EPOCH: LocalDate
    MAX: LocalDate
    MIN: LocalDate
    def compareTo(self, o: Any) -> int: ...
    def until(self, endExclusive: Temporal, unit: TemporalUnit) -> long: ...
    def atStartOfDay(self, zone: ZoneId) -> LocalDateTime: ...
    def atTime(self, *args: Any) -> Union[LocalDateTime, OffsetDateTime]: ...
    @staticmethod
    def now(clock: Optional[Clock] = ...) -> LocalDate: ...
    @staticmethod
    def of(year: int, month: int, dayOfMonth: int) -> LocalDate: ...
    @staticmethod
    def parse(text: CharSequence) -> LocalDate: ...

class LocalDateTime(Object, ChronoLocalDateTime):
    MAX: LocalDateTime
    MIN: LocalDateTime
    def atOffset(self, offset: ZoneOffset) -> OffsetDateTime: ...
    def atZone(self, zone: ZoneId) -> ZonedDateTime: ...
    def toLocalDate(self) -> LocalDate: ...
    def toLocalTime(self) -> LocalTime: ...
    def until(self, endExclusive: Temporal, unit: TemporalUnit) -> long: ...
    def adjustInto(self, temporal: Temporal) -> Temporal: ...
    def compareTo(self, o: Any) -> int: ...

class LocalTime(Object, Temporal, TemporalAdjuster, Comparable):
    MAX: LocalTime
    MIDNIGHT: LocalTime
    MIN: LocalTime
    NOON: LocalTime
    def adjustInto(self, temporal: Temporal) -> Temporal: ...
    def atDate(self, date: LocalDate) -> LocalDateTime: ...
    def compareTo(self, o: Any) -> int: ...
    @staticmethod
    def now(clock: Optional[Clock] = ...) -> LocalTime: ...
    @staticmethod
    def of(
        hour: int, minute: int, second: Optional[int] = ..., nano: Optional[int] = ...
    ) -> LocalTime: ...
    @staticmethod
    def parse(text: CharSequence) -> LocalTime: ...
    def until(self, endExclusive: Temporal, unit: TemporalUnit) -> long: ...

class Month(Enum, TemporalAccessor, TemporalAdjuster):
    JANUARY: Month
    FEBRUARY: Month
    MARCH: Month
    APRIL: Month
    MAY: Month
    JUNE: Month
    JULY: Month
    AUGUST: Month
    SEPTEMBER: Month
    OCTOBER: Month
    NOVEMBER: Month
    DECEMBER: Month
    def adjustInto(self, temporal: Temporal) -> Temporal: ...
    def firstDayOfYear(self, leapYear: bool) -> int: ...
    def firstMonthOfQuarter(self) -> Month: ...
    def getDisplayName(self, style: TextStyle, locale: Locale) -> AnyStr: ...
    def getValue(self) -> int: ...
    def length(self, leapYear: bool) -> int: ...
    def maxLength(self) -> int: ...
    def minLength(self) -> int: ...
    def minus(self, months: long) -> Month: ...
    @staticmethod
    def of(month: int) -> Month: ...
    def plus(self, months: long) -> Month: ...
    @staticmethod
    def values() -> List[Month]: ...

class OffsetDateTime(Object, Temporal, TemporalAdjuster, Comparable):
    MAX: OffsetDateTime
    MIN: OffsetDateTime
    def adjustInto(self, temporal: Temporal) -> Temporal: ...
    def atZoneSameInstant(self, zone: ZoneId) -> ZonedDateTime: ...
    def compareTo(self, o: Any) -> int: ...
    def toLocalDateTime(self) -> LocalDateTime: ...
    def until(self, endExclusive: Temporal, unit: TemporalUnit) -> long: ...

class ZoneId(Object):
    SHORT_IDS: Dict[AnyStr, AnyStr]
    @staticmethod
    def getAvailableZoneIds() -> Set[AnyStr]: ...
    @staticmethod
    def of(
        zoneId: AnyStr, aliasMap: Optional[Dict[AnyStr, AnyStr]] = ...
    ) -> ZoneId: ...
    @staticmethod
    def ofOffset(prefix: AnyStr, offset: ZoneOffset) -> ZoneId: ...
    @staticmethod
    def systemDefault() -> ZoneId: ...

class ZoneOffset(Object):
    MAX: ZoneOffset
    MIN: ZoneOffset
    UTC: ZoneOffset
    @staticmethod
    def of(offsetId: AnyStr) -> ZoneOffset: ...
    @staticmethod
    def ofHours(hours: int) -> ZoneOffset: ...
    @staticmethod
    def ofHoursMinutes(hours: int, minutes: int) -> ZoneOffset: ...
    @staticmethod
    def ofHoursMinutesSeconds(hours: int, minutes: int, seconds: int) -> ZoneOffset: ...
    @staticmethod
    def ofTotalSeconds(totalSeconds: int) -> ZoneOffset: ...

class ZonedDateTime(Object, ChronoZonedDateTime):
    def toLocalDateTime(self) -> LocalDateTime: ...
    def withEarlierOffsetAtOverlap(self) -> ZonedDateTime: ...
    def withLaterOffsetAtOverlap(self) -> ZonedDateTime: ...
    def withZoneSameInstant(self, zone: ZoneId) -> ZonedDateTime: ...
    def withZoneSameLocal(self, zone: ZoneId) -> ZonedDateTime: ...
    def until(self, endExclusive: Temporal, unit: TemporalUnit) -> long: ...
    def compareTo(self, o: Any) -> int: ...
    def getDayOfMonth(self) -> int: ...
    def getDayOfWeek(self) -> DayOfWeek: ...
    def getDayOfYear(self) -> int: ...
    def getHour(self) -> int: ...
    def getMinute(self) -> int: ...
    def getMonth(self) -> Month: ...
    def getMonthValue(self) -> int: ...
    def getNano(self) -> int: ...
    def getOffset(self) -> ZoneOffset: ...
    def getSecond(self) -> int: ...
    def getYear(self) -> int: ...
    def getZone(self) -> ZoneId: ...
    def minusDays(self, days: int) -> ZonedDateTime: ...
    def minusHours(self, hours: int) -> ZonedDateTime: ...
    def minusMinutes(self, minutes: int) -> ZonedDateTime: ...
    def minusMonths(self, months: int) -> ZonedDateTime: ...
    def minusNanos(self, nanos: int) -> ZonedDateTime: ...
    def minusSeconds(self, seconds: int) -> ZonedDateTime: ...
    def minusWeeks(self, weeks: int) -> ZonedDateTime: ...
    def minusYears(self, years: int) -> ZonedDateTime: ...
    @staticmethod
    def now(arg: Optional[Union[Clock, ZoneId]] = ...) -> ZonedDateTime: ...
    @staticmethod
    def of(*args: Any) -> ZonedDateTime: ...
    @staticmethod
    def ofInstant(*args: Any) -> ZonedDateTime: ...
    @staticmethod
    def ofLocal(
        localDateTime: LocalDateTime, zone: ZoneId, preferredOffset: ZoneOffset
    ) -> ZonedDateTime: ...
    @staticmethod
    def ofStrict(
        localDateTime: LocalDateTime, offset: ZoneOffset, zone: ZoneId
    ) -> ZonedDateTime: ...
    @staticmethod
    def parse(
        text: CharSequence, formatter: Optional[DateTimeFormatter] = ...
    ) -> ZonedDateTime: ...



from dev.coatl.helper.types import AnyStr as AnyStr

class LittleEndianInput:
    def available(self) -> int: ...
    def readByte(self) -> int: ...
    def readDouble(self) -> float: ...
    def readFully(self, buf: bytearray, off: int = ..., len: int = ...) -> None: ...
    def readInt(self) -> int: ...
    def readLong(self) -> long: ...
    def readPlain(
        self, buf: bytearray, offset: int = ..., length: int = ...
    ) -> None: ...
    def readShort(self) -> int: ...
    def readUByte(self) -> int: ...
    def readUShort(self) -> int: ...

class LittleEndianOutput:
    def write(self, b: bytearray, offset: int = ..., length: int = ...) -> None: ...
    def writeByte(self, value: int) -> None: ...
    def writeDouble(self, value: float) -> None: ...
    def writeInt(self, value: int) -> None: ...
    def writeShort(self, value: int) -> None: ...
    def writeUTF(self, value: AnyStr) -> None: ...



from typing import Any, Dict, Iterable, List, Mapping, Optional, Set, Union

from dev.coatl.helper.types import AnyStr
from java.io import InputStream, OutputStream
from java.lang import Class, Object
from java.nio import ByteBuffer
from java.time import Instant, ZoneId
from java.util.function import (
    BiFunction,
    Consumer,
    Function,
    Predicate,
    Supplier,
    ToDoubleFunction,
    ToIntFunction,
    ToLongFunction,
)

class Collection:
    def add(self, e: Any) -> bool: ...
    def addAll(self, c: Collection) -> bool: ...
    def clear(self) -> None: ...
    def contains(self, o: Object) -> bool: ...
    def containsAll(self, c: Collection) -> bool: ...
    def equals(self, o: Object) -> bool: ...
    def forEach(self, action: Consumer) -> None: ...
    def hashCode(self) -> int: ...
    def isEmpty(self) -> bool: ...
    def iterator(self) -> Iterator: ...
    def parallelStream(self) -> Stream: ...
    def remove(self, o: Object) -> bool: ...
    def removeAll(self, c: Collection) -> bool: ...
    def removeIf(self, filter: Predicate) -> bool: ...
    def retainAll(self, v: Collection) -> bool: ...
    def size(self) -> int: ...
    def spliterator(self) -> Spliterator: ...
    def stream(self) -> Stream: ...
    def toArray(self, arg: Optional[Any] = ...) -> List[Object]: ...
    def __getitem__(self, key: Union[int, Any]) -> Any: ...
    def __len__(self) -> int: ...

class Comparator:
    def compare(self, o1: Any, o2: Any) -> int: ...
    @staticmethod
    def comparing(keyExtractor: Function, keyComparator: Comparator) -> Comparator: ...
    @staticmethod
    def comparingDouble(keyExtractor: ToDoubleFunction) -> Comparator: ...
    @staticmethod
    def comparingInt(keyExtractor: ToIntFunction) -> Comparator: ...
    @staticmethod
    def comparingLong(keyExtractor: ToLongFunction) -> Comparator: ...
    def equals(self, obj: Object) -> bool: ...
    @staticmethod
    def naturalOrder() -> Comparator: ...
    @staticmethod
    def nullsFirst(comparator: Comparator) -> Comparator: ...
    @staticmethod
    def nullsLast(comparator: Comparator) -> Comparator: ...
    def reversed(self) -> Comparator: ...
    @staticmethod
    def reverseOrder() -> Comparator: ...
    def thenComparing(self, *args: Any) -> Comparator: ...
    def thenComparingDouble(self, keyExtractor: ToDoubleFunction) -> Comparator: ...
    def thenComparingInt(self, keyExtractor: ToIntFunction) -> Comparator: ...
    def thenComparingLong(self, keyExtractor: ToLongFunction) -> Comparator: ...

class Enumeration:
    def asIterator(self) -> Iterator: ...
    def hasMoreElements(self) -> bool: ...
    def nextElement(self) -> Any: ...

class Iterator:
    def forEachRemaining(self, action: Consumer) -> None: ...
    def hasNext(self) -> bool: ...
    def next(self) -> Any: ...
    def remove(self) -> bool: ...

class ListIterator(Iterator):
    def add(self, e: Any) -> None: ...
    def hasNext(self) -> bool: ...
    def hasPrevious(self) -> bool: ...
    def next(self) -> Any: ...
    def nextIndex(self) -> int: ...
    def previous(self) -> Any: ...
    def previousIndex(self) -> int: ...
    def set(self, e: Any) -> None: ...

class Map:
    class Entry:
        @staticmethod
        def comparingByKey(cmp: Optional[Comparator] = ...) -> Any: ...
        @staticmethod
        def comparingByValue(cmp: Optional[Comparator] = ...) -> Any: ...
        def getKey(self) -> Any: ...
        def getValue(self) -> Any: ...
        def hashCode(self) -> int: ...
        def setValue(self, value: Any) -> Any: ...

    def clear(self) -> None: ...
    def compute(self, key: Any, remappingFuntion: BiFunction) -> Any: ...
    def computeIfAbsent(self, key: Any, mappingFuntion: BiFunction) -> Any: ...
    def computeIfPresent(self, key: Any, remappingFuntion: BiFunction) -> Any: ...
    def containsKey(self, key: Object) -> bool: ...
    def containsValue(self, value: Object) -> bool: ...
    @staticmethod
    def copyOf(map: Map) -> Map: ...
    @staticmethod
    def entry(k: Any, v: Any) -> Map.Entry: ...
    def entrySet(self) -> Set[Map.Entry]: ...
    def forEach(self, action: BiFunction) -> None: ...
    def get(self, key: Object) -> Any: ...
    def getOrDefault(self, key: Object, defaultValue: Any) -> Any: ...
    def isEmpty(self) -> bool: ...
    def keySet(self) -> Set[Any]: ...
    def merge(self, key: Any, value: Any, remappingFunction: BiFunction) -> Any: ...
    @staticmethod
    def of(*args: Any) -> Map: ...
    @staticmethod
    def ofEntries(*entries: Map.Entry) -> Map: ...
    def put(self, key: Any, value: Any) -> Any: ...
    def putAll(self, m: Mapping[Any, Any]) -> None: ...
    def putIfAbsent(self, key: Any, value: Any) -> Any: ...
    def remove(self, key: Object) -> Any: ...
    def replace(self, *args: Any) -> Union[Any, bool]: ...
    def replaceAll(self, function: BiFunction) -> None: ...
    def size(self) -> int: ...
    def values(self) -> Collection: ...

class Spliterator:
    CONCURRENT: int
    DISTINCT: int
    IMMUTABLE: int
    NONNULL: int
    ORDERED: int
    SIZED: int
    SORTED: int
    SUBSIZED: int
    def characteristics(self) -> int: ...
    def estimateSize(self) -> long: ...
    def forEachRemaining(self, action: Consumer) -> None: ...
    def getComparator(self) -> Comparator: ...
    def getExactSizeIfKnown(self) -> long: ...
    def hasCharacteristics(self, characteristics: int) -> bool: ...
    def tryAdvance(self, action: Consumer) -> bool: ...
    def trySplit(self) -> Spliterator: ...

class Stream:
    class Builder(Consumer):
        def accept(self, t: Any) -> None: ...
        def add(self, t: Any) -> Stream.Builder: ...
        def build(self) -> Stream: ...

    @staticmethod
    def builder() -> Builder: ...
    @staticmethod
    def concat(a: Stream, b: Stream) -> Stream: ...
    @staticmethod
    def empty() -> Stream: ...
    @staticmethod
    def generate(s: Supplier) -> Stream: ...
    @staticmethod
    def iterate(*args: Any) -> Stream: ...
    @staticmethod
    def of(*args: Any) -> Stream: ...
    @staticmethod
    def ofNullable(t: Any) -> Stream: ...

class Arrays(Object):
    @staticmethod
    def asList(a: Any) -> List[Any]: ...
    @staticmethod
    def binarySearch(*args: Any, **kwargs: Any) -> int: ...
    @staticmethod
    def compare(*args: Any, **kwargs: Any) -> int: ...
    @staticmethod
    def compareUnsigned(*args: Any, **kwargs: Any) -> int: ...
    @staticmethod
    def copyOf(
        original: List[Any], newLength: int, newType: Optional[Class] = ...
    ) -> List[Any]: ...
    @staticmethod
    def copyOfRange(
        original: List[Any], from_: int, to: int, newType: Optional[Class] = ...
    ) -> List[Any]: ...
    @staticmethod
    def deepEquals(a1: List[Object], a2: List[Object]) -> bool: ...
    @staticmethod
    def equals(*args: Any, **kwargs: Any) -> bool: ...
    @staticmethod
    def fill(a: List[Any], *args: Any) -> None: ...
    @staticmethod
    def mismatch(*args: Any, **kwargs: Any) -> int: ...
    @staticmethod
    def parallelPrefix(*args: Any, **kwargs: Any) -> None: ...
    @staticmethod
    def parallelSetAll(*args: Any, **kwargs: Any) -> None: ...
    @staticmethod
    def parallelSort(*args: Any, **kwargs: Any) -> None: ...
    @staticmethod
    def setAll(*args: Any, **kwargs: Any) -> None: ...
    @staticmethod
    def sort(*args: Any, **kwargs: Any) -> None: ...
    @staticmethod
    def spliterator(
        array: Iterable[Any],
        startInclusive: Optional[int] = ...,
        endExclusive: Optional[int] = ...,
    ) -> Spliterator: ...
    @staticmethod
    def stream(
        array: Iterable[Any],
        startInclusive: Optional[int] = ...,
        endExclusive: Optional[int] = ...,
    ) -> Stream: ...

class AbstractCollection(Object, Collection):
    def add(self, e: Any) -> bool: ...
    def addAll(self, c: Collection) -> bool: ...
    def clear(self) -> None: ...
    def contains(self, o: Object) -> bool: ...
    def containsAll(self, c: Collection) -> bool: ...
    def isEmpty(self) -> bool: ...
    def iterator(self) -> Iterator: ...
    def remove(self, o: Object) -> bool: ...
    def removeAll(self, c: Collection) -> bool: ...
    def retainAll(self, v: Collection) -> bool: ...
    def size(self) -> int: ...

class AbstractList(AbstractCollection):
    def indexOf(self, o: Object) -> int: ...
    def lastIndexOf(self, o: Object) -> int: ...
    def listIterator(self, index: Optional[int] = ...) -> ListIterator: ...
    def set(self, index: int, element: Any) -> Any: ...
    def subList(self, fromIndex: int, toIndex: int) -> List[Any]: ...

class AbstractMap(Object, Map):
    def clear(self) -> None: ...
    def containsKey(self, key: Object) -> bool: ...
    def containsValue(self, value: Object) -> bool: ...
    def entrySet(self) -> Set[Map.Entry]: ...
    def get(self, key: Object) -> Any: ...
    def isEmpty(self) -> bool: ...
    def keySet(self) -> Set[Any]: ...
    def put(self, key: Any, value: Any) -> Any: ...
    def putAll(self, m: Mapping[Any, Any]) -> None: ...
    def remove(self, key: Object) -> Any: ...
    def size(self) -> int: ...
    def values(self) -> Collection: ...

class ArrayList(AbstractList):
    def __init__(self, *args: Any) -> None: ...
    def ensureCapacity(self, minCapacity: int) -> None: ...
    def get(self, index: int) -> Any: ...
    def trimToSize(self) -> None: ...

class Base64(Object):
    class Decoder(Object):
        def decode(
            self,
            arg: Union[AnyStr, ByteBuffer, List[int]],
            dst: Optional[List[int]] = ...,
        ) -> Union[ByteBuffer, int, List[int]]: ...
        def wrap(self, is_: InputStream) -> InputStream: ...

    class Encoder(Object):
        def encode(
            self, arg: Union[ByteBuffer, List[int]], dst: Optional[List[int]] = ...
        ) -> Union[ByteBuffer, int, List[int]]: ...
        def encodeToString(self, src: List[int]) -> AnyStr: ...
        def withoutPadding(self) -> Base64.Encoder: ...
        def wrap(self, os: OutputStream) -> OutputStream: ...

    @staticmethod
    def getDecoder() -> Base64.Decoder: ...
    @staticmethod
    def getEncoder() -> Base64.Encoder: ...
    @staticmethod
    def getMimeDecoder() -> Base64.Decoder: ...
    @staticmethod
    def getMimeEncoder(
        lineLength: Optional[int] = ..., lineSeparator: Optional[List[int]] = ...
    ) -> Base64.Encoder: ...
    @staticmethod
    def getUrlDecoder() -> Base64.Decoder: ...
    @staticmethod
    def getUrlEncoder() -> Base64.Encoder: ...

class Calendar(Object):
    ALL_STYLES: int
    AM: int
    AM_PM: int
    APRIL: int
    AUGUST: int
    DATE: int
    DAY_OF_MONTH: int
    DAY_OF_WEEK: int
    DAY_OF_WEEK_IN_MONTH: int
    DAY_OF_YEAR: int
    DECEMBER: int
    DST_OFFSET: int
    ERA: int
    FEBRUARY: int
    FIELD_COUNT: int
    FRIDAY: int
    HOUR: int
    HOUR_OF_DAY: int
    JANUARY: int
    JULY: int
    JUNE: int
    LONG: int
    LONG_FORMAT: int
    LONG_STANDALONE: int
    MARCH: int
    MAY: int
    MILLISECOND: int
    MINUTE: int
    MONDAY: int
    MONTH: int
    NARROW_FORMAT: int
    NARROW_STANDALONE: int
    NOVEMBER: int
    OCTOBER: int
    PM: int
    SATURDAY: int
    SECOND: int
    SEPTEMBER: int
    SHORT: int
    SHORT_FORMAT: int
    SHORT_STANDALONE: int
    SUNDAY: int
    THURSDAY: int
    TUESDAY: int
    UNDECIMBER: int
    WEDNESDAY: int
    WEEK_OF_MONTH: int
    WEEK_OF_YEAR: int
    YEAR: int
    ZONE_OFFSET: int
    def add(self, field: int, amount: int) -> None: ...
    def after(self, when: Object) -> bool: ...
    def before(self, when: Object) -> bool: ...
    def clear(self, field: Optional[int] = ...) -> None: ...
    def clone(self) -> Object: ...
    def compareTo(self, anotherCalendar: Calendar) -> int: ...
    def get(self, field: int) -> int: ...
    def getActualMaximum(self, field: int) -> int: ...
    def getActualMinimum(self, field: int) -> int: ...
    @staticmethod
    def getAvailableCalendarTypes() -> Set[AnyStr]: ...
    @staticmethod
    def getAvailableLocales() -> List[Locale]: ...
    def getCalendarType(self) -> AnyStr: ...
    def getDisplayName(self, field: int, style: int, locale: Locale) -> AnyStr: ...
    def getDisplayNames(
        self, field: int, style: int, locale: Locale
    ) -> Dict[AnyStr, int]: ...
    def getFirstDayOfWeek(self) -> int: ...
    def getGreatestMinimum(self, field: int) -> int: ...
    @staticmethod
    def getInstance(*args: Any) -> Calendar: ...
    def getLeastMaximum(self, field: int) -> int: ...
    def getMaximum(self, field: int) -> int: ...
    def getMinimalDaysInFirstWeek(self) -> int: ...
    def getMinimum(self, field: int) -> int: ...
    def getTime(self) -> Date: ...
    def getTimeInMillis(self) -> long: ...
    def getTimeZone(self) -> TimeZone: ...
    def getWeeksInWeekYear(self) -> int: ...
    def getWeekYear(self) -> int: ...
    def isLenient(self) -> bool: ...
    def isSet(self, field: int) -> bool: ...
    def isWeekDateSUpported(self) -> bool: ...
    def roll(self, field: int, amount: int) -> None: ...
    def set(self, *args: int) -> None: ...
    def setFirstDayOfWeek(self, value: int) -> None: ...
    def setLenient(self, lenient: bool) -> None: ...
    def setMinimalDaysInFirstWeek(self, value: int) -> None: ...
    def setTime(self, date: Date) -> None: ...
    def setTimeInMillis(self, millis: long) -> None: ...
    def setTimeZone(self, value: TimeZone) -> None: ...
    def setWeekDate(self, weekYear: int, weekOfYear: int, dayOfWeek: int) -> None: ...
    def toInstant(self) -> Instant: ...

class Currency(Object):
    @staticmethod
    def getAvailableCurrencies() -> Set[Currency]: ...
    def getCurrencyCode(self) -> AnyStr: ...
    def getDisplayName(self, locale: Optional[Locale] = ...) -> AnyStr: ...
    @staticmethod
    def getInstance(arg: Union[Locale, AnyStr]) -> Currency: ...
    def getNumericCode(self) -> int: ...
    def getNumericCodeAsString(self) -> AnyStr: ...
    def getSymbol(self, locale: Optional[Locale] = ...) -> AnyStr: ...

class Date(Object):
    def __init__(self, date: Optional[long] = ...) -> None: ...
    def after(self, when: Date) -> bool: ...
    def before(self, when: Date) -> bool: ...
    def compareTo(self, anotherDate: Date) -> int: ...
    def getTime(self) -> long: ...
    def setTime(self, time: long) -> None: ...

class Dictionary(Object):
    def __init__(self) -> None: ...
    def elements(self) -> Enumeration: ...
    def get(self, key: Object) -> Any: ...
    def isEmpty(self) -> bool: ...
    def keys(self) -> Enumeration: ...
    def put(self, key: Any, value: Any) -> Any: ...
    def remove(self, key: Object) -> Any: ...
    def size(self) -> int: ...

class EventObject(Object):
    def __init__(self, source: Object) -> None: ...
    def getSource(self) -> Object: ...

class HashMap(AbstractMap, Map):
    def __init__(self, *args: Any) -> None: ...
    def entrySet(self) -> Set[Map.Entry]: ...

class Hashtable(Dictionary, Map):
    def __init__(self, *args: Any) -> None: ...
    def clear(self) -> None: ...
    def clone(self) -> Object: ...
    def contains(self, value: Object) -> bool: ...
    def containsKey(self, key: Object) -> bool: ...
    def containsValue(self, value: Object) -> bool: ...
    def elements(self) -> Enumeration: ...
    def entrySet(self) -> Set[Map.Entry]: ...
    def get(self, key: Object) -> Any: ...
    def isEmpty(self) -> bool: ...
    def keySet(self) -> Set[Any]: ...
    def keys(self) -> Enumeration: ...
    def put(self, key: Any, value: Any) -> Any: ...
    def putAll(self, m: Mapping[Any, Any]) -> None: ...
    def remove(self, key: Object) -> Any: ...
    def size(self) -> int: ...
    def values(self) -> Collection: ...

class Locale(Object):
    country: Optional[str]
    language: str
    variant: Optional[str]
    def __init__(
        self, language: str, country: Optional[str] = ..., variant: Optional[str] = ...
    ) -> None: ...
    def CANADA(self) -> Locale: ...
    def CANADA_FRENCH(self) -> Locale: ...
    def CHINA(self) -> Locale: ...
    def CHINESE(self) -> Locale: ...
    def ENGLISH(self) -> Locale: ...
    def FRANCE(self) -> Locale: ...
    def FRENCH(self) -> Locale: ...
    def GERMAN(self) -> Locale: ...
    def GERMANY(self) -> Locale: ...
    def ITALIAN(self) -> Locale: ...
    def ITALY(self) -> Locale: ...
    def JAPAN(self) -> Locale: ...
    def JAPANESE(self) -> Locale: ...
    def KOREA(self) -> Locale: ...
    def KOREAN(self) -> Locale: ...
    def PRC(self) -> Locale: ...
    def SIMPLIFIED_CHINESE(self) -> Locale: ...
    def TAIWAN(self) -> Locale: ...
    def TRADITIONAL_CHINESE(self) -> Locale: ...
    def UK(self) -> Locale: ...
    def US(self) -> Locale: ...

class Properties(Hashtable):
    def __init__(self, *args: Any) -> None: ...

class TimeZone(Object):
    LONG: int
    SHORT: int
    def __init__(self) -> None: ...
    def clone(self) -> Object: ...
    @staticmethod
    def getAvailableIDs(rawOffset: Optional[int] = ...) -> List[AnyStr]: ...
    @staticmethod
    def getDefault() -> TimeZone: ...
    def getDisplayName(self, *args: Any) -> AnyStr: ...
    def getDSTSavings(self) -> int: ...
    def getID(self) -> AnyStr: ...
    def getOffset(self, *args: Any) -> int: ...
    def getRawOffset(self) -> int: ...
    @staticmethod
    def getTimeZone(arg: Union[AnyStr, ZoneId]) -> TimeZone: ...
    def hasSameRules(self, other: TimeZone) -> bool: ...
    def isDaylightTime(self, date: Date) -> bool: ...
    def observesDaylightTime(self) -> bool: ...
    @staticmethod
    def setDefault(zone: TimeZone) -> None: ...
    def setID(self, ID: AnyStr) -> None: ...
    def setRawOffset(self, offsetMillis: int) -> None: ...
    def toZoneId(self) -> ZoneId: ...
    def useDaylightTime(self) -> bool: ...

class UUID(Object):
    def __init__(self, mostSigBits: long, leastSigBits: long) -> None: ...
    def clockSequence(self) -> int: ...
    def compareTo(self, val: UUID) -> int: ...
    @staticmethod
    def fromString(name: AnyStr) -> UUID: ...
    def getLeastSignificantBits(self) -> long: ...
    def getMostSignificantBits(self) -> long: ...
    @staticmethod
    def nameUUIDFromBytes(name: bytearray) -> UUID: ...
    def node(self) -> long: ...
    @staticmethod
    def randomUUID() -> UUID: ...
    def timestamp(self) -> long: ...
    def variant(self) -> int: ...
    def version(self) -> int: ...



from typing import Any, List, Set

from dev.coatl.helper.types import AnyStr as AnyStr
from org.apache.poi.hpsf import ClassID

class Entry:
    def delete(self) -> bool: ...
    def getName(self) -> AnyStr: ...
    def getParent(self) -> DirectoryEntry: ...
    def isDirectoryEntry(self) -> bool: ...
    def isDocumentEntry(self) -> bool: ...
    def renameTo(self, newName: AnyStr) -> None: ...

class DirectoryEntry(Entry):
    def createDirectory(self, name: AnyStr) -> DirectoryEntry: ...
    def createDocument(self, *args: Any) -> None: ...
    def delete(self) -> bool: ...
    def getEntries(self) -> List[Entry]: ...
    def getEntry(self, name: AnyStr) -> Entry: ...
    def getEntryCount(self) -> int: ...
    def getEntryNames(self) -> Set[AnyStr]: ...
    def getName(self) -> AnyStr: ...
    def getParent(self) -> DirectoryEntry: ...
    def getStorageClsid(self) -> ClassID: ...
    def hasEntry(self, name: AnyStr) -> bool: ...
    def isDirectoryEntry(self) -> bool: ...
    def isDocumentEntry(self) -> bool: ...
    def isEmpty(self) -> bool: ...
    def renameTo(self, newName: AnyStr) -> None: ...
    def setStorageClsid(self, clsidStorage: ClassID) -> None: ...
